@@ -11,11 +11,15 @@ final class Tag
 {
     /**
      * The required key portion of the tag.
+     *
+     * @var string
      */
     private $key;
 
     /**
      * The optional value portion of the tag.
+     *
+     * @var string
      */
     private $value;
 
@@ -27,10 +31,16 @@ final class Tag
      */
     public function __construct(array $input)
     {
-        $this->key = $input['Key'] ?? null;
-        $this->value = $input['Value'] ?? null;
+        $this->key = $input['Key'] ?? $this->throwException(new InvalidArgument('Missing required field "Key".'));
+        $this->value = $input['Value'] ?? $this->throwException(new InvalidArgument('Missing required field "Value".'));
     }
 
+    /**
+     * @param array{
+     *   Key: string,
+     *   Value: string,
+     * }|Tag $input
+     */
     public static function create($input): self
     {
         return $input instanceof self ? $input : new self($input);
@@ -52,15 +62,19 @@ final class Tag
     public function requestBody(): array
     {
         $payload = [];
-        if (null === $v = $this->key) {
-            throw new InvalidArgument(sprintf('Missing parameter "Key" for "%s". The value cannot be null.', __CLASS__));
-        }
+        $v = $this->key;
         $payload['Key'] = $v;
-        if (null === $v = $this->value) {
-            throw new InvalidArgument(sprintf('Missing parameter "Value" for "%s". The value cannot be null.', __CLASS__));
-        }
+        $v = $this->value;
         $payload['Value'] = $v;
 
         return $payload;
     }
+
+    /**
+     * @return never
+     */
+    private function throwException(\Throwable $exception)
+    {
+        throw $exception;
+    }
 }
